# Load DICOM 

::: imgtools.dicom.load_dicom
    options:
        show_root_full_path: true
        show_docstring_raises: true


::: imgtools.dicom.load_rtstruct_dcm
    options:
        show_root_full_path: true
        show_docstring_raises: true

::: imgtools.dicom.load_seg_dcm
    options:
        show_root_full_path: true
        show_docstring_raises: true
